import re

from podcast_scraper.generic_parser import GenericParser


class FranceCulture(GenericParser):
    def get_urls(self, content):

        album = (
            re.compile(
                r"[\s]*<h1>([\s\S]+?)(?:-[\s\S]+)?[\s]*</h1>", flags=re.MULTILINE
            )
            .findall(content)[0]
            .strip()
        )

        urls = []
        titles = []
        dates = []
        for (url, title, date) in re.compile(
            r'data-url="(.+?\.mp3)"[\s\S]+?<span class="teaser-text-title-wrapper"> *(.+?) *</span>[\s\S]+?<div class="teaser-text-date"><span>LE[\s\S]*?(\d\d/\d\d/\d\d\d\d)</span></div>',
            flags=re.MULTILINE,
        ).findall(content):
            urls.append(url)
            titles.append(title)
            dates.append(date)

        files = [i.split("/")[-1] for i in urls]

        return {
            "album": [album] * len(titles),
            "title": titles,
            "date": dates,
            "file": files,
            "url": urls,
        }

    def get_next(self, webdriver):
        try:
            next = webdriver.find_element_by_css_selector(
                "#main-content > article > section > div.teasers-list > div.pager-container > ul > li.pager-item.next > a"
            )
            new_url = next.get_attribute("href")
            webdriver.get(new_url)
            return new_url
        except Exception as e:
            return False



import abc
import os

from selenium.webdriver import DesiredCapabilities
from testcontainers.selenium import BrowserWebDriverContainer
import pandas as pd


class GenericParser:

    extracted_content = []

    @abc.abstractmethod
    def get_urls(self, content):
        ...

    @abc.abstractmethod
    def get_next(self, webdriver):
        ...

    def connect(self, webdriver, user, password):
        # dummy implementation, to be overrided
        pass

    def format_url(self):
        df = pd.concat([pd.DataFrame(url) for url in self.extracted_content])
        print(df.to_csv(index=None))

    def print_urls(self, url, page_number=-1):
        with BrowserWebDriverContainer(DesiredCapabilities.CHROME) as chrome:
            webdriver = chrome.get_driver()
            webdriver.get(url)
            self.connect(
                webdriver, os.getenv("USER", None), os.getenv("PASSWORD", None)
            )
            content = webdriver.page_source

            self.extracted_content.append(self.get_urls(content))
            page_count = 1
            while bool(self.get_next(webdriver)) and (
                page_number == -1 or page_count < page_number
            ):
                result = webdriver.page_source
                self.extracted_content.append(self.get_urls(result))
                page_count += 1

            self.format_url()



import re
import time

from selenium.webdriver.chrome.webdriver import WebDriver

from podcast_scraper.generic_parser import GenericParser


class MondeDiplo(GenericParser):
    def connect(self, webdriver: WebDriver, user, password):
        connect = webdriver.find_element_by_css_selector("#session_connexion")
        connect.click()
        time.sleep(3)
        user_field = webdriver.find_element_by_css_selector(
            "#identification_sso > ul > li:nth-child(1) > input[type=email]"
        )
        user_field.send_keys(user)
        password_field = webdriver.find_element_by_css_selector(
            "#identification_sso > ul > li:nth-child(2) > input"
        )
        password_field.send_keys(password)
        validate = webdriver.find_element_by_css_selector(
            "#identification_sso > ul > li.submit > input[type=submit]"
        )
        validate.click()
        time.sleep(5)

    def get_urls(self, content):
        p = re.compile(
            r'<div class="track"><a href="(.+?\.mp3\?cle=[^"]+)"(?=[\s\S]+lien_pagination)',
            flags=re.MULTILINE,
        )
        m = p.findall(content)
        return {"url": m}

    def get_next(self, webdriver: WebDriver):
        try:
            next = webdriver.find_element_by_link_text("→")
            new_url = next.get_attribute("href")
            webdriver.get(new_url)
            return new_url
        except Exception as e:
            return False



import click

from podcast_scraper.france_culture import FranceCulture
from podcast_scraper.monde_diplo import MondeDiplo


@click.group()
def click_france_culture():
    pass


@click_france_culture.command()
@click.option(
    "--url",
    default="https://www.franceculture.fr/emissions/carbone-14-le-magazine-de-larcheologie",
)
@click.option("--pages", default=-1)
def france_culture(url, pages):
    """Get podcast url for France Culture"""
    FranceCulture().print_urls(url, pages)


@click.group()
def click_monde_diplo():
    pass


@click_monde_diplo.command()
@click.option(
    "--url",
    default="https://www.monde-diplomatique.fr/audio?debut_sons=0#pagination_sons",
)
@click.option("--pages", default=-1)
def monde_diplo(url, pages):
    """Get podcast url for Monde Diplo"""
    MondeDiplo().print_urls(url, pages)


cli = click.CommandCollection(sources=[click_france_culture, click_monde_diplo])

if __name__ == "__main__":
    cli()
